TradingClient

Struct TradingClient 

pub struct TradingClient {
    pub api_key: String,
    pub base_url: Url,
    /* private fields */
}
The client for the Lemon API.

Fields

api_key: String

The API key.

base_url: Url

The base url for the API

Implementations

Source

impl TradingClient

pub fn get_order( &self, id: Option<String>, ) -> Result<GenericResponse<OrderResults>, Error>

Get orders

pub fn post_order( &self, _body: OrderPlacing, ) -> Result<GenericResponse<OrderResults>, Error>

Post and create a new order.

pub fn activate_order( &self, pin: i64, order_id: &str, ) -> Result<Response, Error>

Activate an order by id

pub fn delete_order(&self, order_id: &str) -> Result<Response, Error>

Delete an order by id

Source

impl TradingClient

pub fn get_account_withdrawls( &self, _limit: Option<i32>, _page: Option<i32>, ) -> Result<Response, Error>

Get account withdrawls

pub fn post_withdrawal( &self, withdrawal: WithdrawalRequest, ) -> Result<Response, Error>

Submit a new withdrawal TODO: Add docs for params

Source

impl TradingClient

pub fn get_account_information( &self, ) -> Result<AccountInformation<AccountResults>, Error>

Get account information

Source

impl TradingClient

pub fn get_positions_performance( &self, ) -> Result<PaginationResponse<PositionPerformance>, Error>

Get an overview of your position performances Using this endpoint, you can retrieve when positions were opened and closed, potential profits/losses, or related fees for position orders.

Source

impl TradingClient

pub fn get_statements( &self, limit: Option<i64>, page: Option<u32>, ) -> Result<PaginationResponse<Statement>, Error>

Get all change events happening to your positions.

Source

impl TradingClient

pub fn get_positions(&self) -> Result<PaginationResponse<Position>, Error>

Get all positions

Source

impl TradingClient

pub fn new(api_key: String, _endpoint: &str) -> Self

Create a new TradingClient

pub fn paper_client(api_key: &str) -> Self

Create a new client for paper trading with the given API key.

pub fn live_client(api_key: String) -> Self

Create a new client for live trading with the given API key.